:
# NAME:
#	install_new.sh - install new file if different from old
#
# SYNOPSIS:
#	install_new.sh [options] "file" ...
#	install_xnew.sh [options][-v]
#
# DESCRIPTION:
#	For each "file".new if it is different to "file" install it as
#	"file".	 If a previous "file" existed, save it as "file".old
#	It can be run as a script or included in other scripts.
#
#	If run as 'install_xnew' it reads "file"s from stdin and if
#	the '-v' option is given it echos "file"s which are installed to
#	stdout.
#
#	Options:
#
#	-v	Print the name of installed files to stdout.
#
#	-o "owner"
#	-g "group"
#	-m "mode"
#		Set owner, group, mode as specified.
#
#	-k	Keep owner, group, mode of .old file.
#		Overridden by '-o' etc.
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>

# RCSid:
#	$Id: install_new.sh,v 1.9 2005/11/10 00:02:19 sjg Exp $
#
#	@(#) Copyright (c) 1993 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net

NewExt=new
OldExt=old

# all this just for chown!
add_path () { [ -d $1 ] && eval ${2:-PATH}="\$${2:-PATH}:$1"; }
add_path /etc
add_path /usr/etc
add_path /sbin
add_path /usr/sbin
add_path /usr/local/share/bin
add_path /share/bin
add_path ${RC_D:-/etc/rc_d}

file_info() {
        :
}


install_if_new() {
        old_group=
        old_owner=
        old_mode=
        
	if test -s $1.$NewExt; then
		if test -f $1; then
			if cmp -s $1 $1.$NewExt; then
				rm -f $1.$NewExt
			else
                                eval `file_info -m $1 old`
				rm -f $1.$OldExt
				mv $1 $1.$OldExt 
			fi
		fi
	else
		rm -f $1.$NewExt
	fi
        
	if test -s $1.$NewExt; then
	        [ x${opt_g:-$old_group} = x ] || ${CHGRP:-chgrp} ${opt_g:-$old_group} $1.$NewExt
		[ x${opt_g:-$old_owner} = x ] || ${CHOWN:-chown} ${opt_o:-$old_owner} $1.$NewExt
		[ x${opt_m:-$old_mode} = x ] || ${CHMOD:-chmod} ${opt_m:-$old_mode} $1.$NewExt
                mv $1.$NewExt $1 && { ${ECHO:-:} $1; return 0; }
	fi
	return 1
}

case $0 in
*install_*new*)
        opt_str=o:m:g:kv
        . setopts.sh
        KEEP_MODES=${KEEP_MODES:-$opt_k}
        ECHO=${opt_v:+echo}
        ;;
esac

case "$KEEP_MODES" in
"") ;;
*) . finfo.sh;;
esac

case $0 in
*install_*new*)
    case "${1:--}" in
    -)
	sed "s,\.$NewExt\$,," $* | while read file
	do
		install_if_new $file
	done
	;;
    *)
	for file in $*
	do
	    install_if_new $file
	done
	;;
    esac
    ;;
esac
